@@ -4,12 +4,14 @@ from collections import namedtuple
 from datetime import datetime
 from functools import wraps
 from typing import List, Iterable
+import os
+import os.path
 
 from loguru import logger
 import pytz
 import requests
 
-__version__ = "0.1.12"
+__version__ = "0.1.13"
 
 
 def pairwise(iterable):
